function g = gblur(a,s,K)
%
% gblur: blurs an image with a Gaussian window
% On input:
%           a: image
%           s: standard deviation
%           K: window size
% On output:
%           g: blurred version of a
% Call:
%     g = gblur(a,s,K)
%

k = (K-1)/2;
[m n] = size(a);
gmask = gauss(s,K);
g = conv2(a,gmask);
[gm gn] = size(g);
g = g((1+k):gm-k,(1+k):gn-k);
